==> ozone-1.3.0-src.tar.gz: ozone-1.3.0-src/hadoop-hdds/erasurecode/src/test/java/org/apache/ozone/erasurecode/rawcoder/TestRawErasureCoderBenchmark.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.ozone.erasurecode.rawcoder;

import org.junit.Test;

/**
 * Tests for the raw erasure coder benchmark tool.
 */
public class TestRawErasureCoderBenchmark {

  @Test
  public void testDummyCoder() throws Exception {
    // Dummy coder
    RawErasureCoderBenchmark.performBench("encode",
        RawErasureCoderBenchmark.CODER.DUMMY_CODER, 2, 100, 1024);
    RawErasureCoderBenchmark.performBench("decode",
        RawErasureCoderBenchmark.CODER.DUMMY_CODER, 5, 150, 100);
  }

  @Test
  public void testRSCoder() throws Exception {
    // RS Java coder
    RawErasureCoderBenchmark.performBench("encode",
        RawErasureCoderBenchmark.CODER.RS_CODER, 3, 200, 200);
    RawErasureCoderBenchmark.performBench("decode",
        RawErasureCoderBenchmark.CODER.RS_CODER, 4, 135, 20);
  }

}

==> ozone-1.4.1-src.tar.gz: ozone-1.4.1-src/hadoop-hdds/erasurecode/src/test/java/org/apache/ozone/erasurecode/rawcoder/TestRawErasureCoderBenchmark.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.ozone.erasurecode.rawcoder;

import org.junit.jupiter.api.Test;

/**
 * Tests for the raw erasure coder benchmark tool.
 */
public class TestRawErasureCoderBenchmark {

  @Test
  public void testDummyCoder() throws Exception {
    // Dummy coder
    RawErasureCoderBenchmark.performBench("encode",
        RawErasureCoderBenchmark.CODER.DUMMY_CODER, 2, 100, 1024);
    RawErasureCoderBenchmark.performBench("decode",
        RawErasureCoderBenchmark.CODER.DUMMY_CODER, 5, 150, 100);
  }

  @Test
  public void testRSCoder() throws Exception {
    // RS Java coder
    RawErasureCoderBenchmark.performBench("encode",
        RawErasureCoderBenchmark.CODER.RS_CODER, 3, 200, 200);
    RawErasureCoderBenchmark.performBench("decode",
        RawErasureCoderBenchmark.CODER.RS_CODER, 4, 135, 20);
  }

}
